package edu.ucla.sspace.graph;

import java.util.Set;


/**
 * An interface for representing a set of types and methods to compare
 * instantations of those types on various graphical constructions.
 *
 * @see Multigraph
 * @see TypedEdge
 */
public interface TypeSemantics<T> {

    /**
     * Returns the similarity of the two raw types.
     */
    double similarity(T t1, T t2);

    /**
     * Returns the similarity of the two edges with their specified types.
     */ 
    double similarity(TypedEdge<? extends T> t1, TypedEdge<? extends T> t2);

    /**
     * Returns the set of types represented in this type semantics (optional
     * operation).  If the full set of types is not known a priori (e.g., the
     * similarity computed on the basis of features, or just type equality), an
     * implementation may return the empty set.
     */
    Set<T> getTypes();
}